//$Id: resizeable.cc,v 1.8 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "resizeable.h"

#include <sigc++/signal_system.h>

using namespace Guikachu::Widgets;

Resizeable::Resizeable (Property<int> &real_width,
			Property<int> &real_height):
    width (real_width),
    height (real_height)
{
}

int Resizeable::get_display_width  () const
{
    return width;
}

int Resizeable::get_display_height () const
{
    return height;
}
